@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2015-09-12'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $DATE = '2015-09-15'; # DATE
+our $VERSION = '0.26'; # VERSION
 
 use 5.010001;
 use strict;
@@ -34,6 +34,7 @@ has summary => (is=>'rw');
 has cmdline => (is=>'rw');
 has prefer_lite => (is=>'rw');
 has enable_log => (is=>'rw');
+has pass_cmdline_object => (is=>'rw');
 has default_log_level => (is=>'rw');
 has extra_urls_for_version => (is=>'rw');
 has config_filename => (is=>'rw');
@@ -133,6 +134,7 @@ sub munge_files {
             log => $self->enable_log,
             ($self->extra_urls_for_version ? (extra_urls_for_version => [split(/\s*,\s*/, $self->extra_urls_for_version)]) : ()),
             default_log_level => $self->default_log_level,
+            pass_cmdline_object => $self->pass_cmdline_object,
             cmdline => $self->cmdline,
             prefer_lite => $self->prefer_lite,
             ssl_verify_hostname => $self->ssl_verify_hostname,
@@ -224,7 +226,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.25 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-09-12.
+This document describes version 0.26 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-09-15.
 
 =head1 SYNOPSIS
 
@@ -348,6 +350,10 @@ If set, will add this code to the generated script:
 
 This can be used if you want your script to be verbose by default, for example.
 
+=head2 pass_cmdline_object => bool
+
+Will be passed to Perinci::CmdLine object construction code.
+
 =head2 extra_urls_for_version => str
 
 Comma-separated string, will be passed to Perinci::CmdLine object construction
@@ -398,7 +404,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-ScriptFromFunc>.
+Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-GenPericmdScript>.
 
 =head1 BUGS
 
